==> zio-aws-servicecatalog_2.13-5.17.151.2-sources.jar: zio/aws/servicecatalog/model/RejectPortfolioShareRequest.scala <==
package zio.aws.servicecatalog.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.servicecatalog.model.primitives.{Id, AcceptLanguage}
import scala.jdk.CollectionConverters._
final case class RejectPortfolioShareRequest(
    acceptLanguage: Option[AcceptLanguage] = None,
    portfolioId: Id,
    portfolioShareType: Option[
      zio.aws.servicecatalog.model.PortfolioShareType
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.servicecatalog.model.RejectPortfolioShareRequest = {
    import RejectPortfolioShareRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.servicecatalog.model.RejectPortfolioShareRequest
      .builder()
      .optionallyWith(
        acceptLanguage.map(value =>
          AcceptLanguage.unwrap(value): java.lang.String
        )
      )(_.acceptLanguage)
      .portfolioId(Id.unwrap(portfolioId): java.lang.String)
      .optionallyWith(portfolioShareType.map(value => value.unwrap))(
        _.portfolioShareType
      )
      .build()
  }
  def asReadOnly
      : zio.aws.servicecatalog.model.RejectPortfolioShareRequest.ReadOnly =
    zio.aws.servicecatalog.model.RejectPortfolioShareRequest
      .wrap(buildAwsValue())
}
object RejectPortfolioShareRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.servicecatalog.model.RejectPortfolioShareRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.servicecatalog.model.RejectPortfolioShareRequest =
      zio.aws.servicecatalog.model.RejectPortfolioShareRequest(
        acceptLanguage.map(value => value),
        portfolioId,
        portfolioShareType.map(value => value)
      )
    def acceptLanguage: Option[AcceptLanguage]
    def portfolioId: Id
    def portfolioShareType
        : Option[zio.aws.servicecatalog.model.PortfolioShareType]
    def getAcceptLanguage: ZIO[Any, AwsError, AcceptLanguage] =
      AwsError.unwrapOptionField("acceptLanguage", acceptLanguage)
    def getPortfolioId: ZIO[Any, Nothing, Id] = ZIO.succeed(portfolioId)
    def getPortfolioShareType
        : ZIO[Any, AwsError, zio.aws.servicecatalog.model.PortfolioShareType] =
      AwsError.unwrapOptionField("portfolioShareType", portfolioShareType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.servicecatalog.model.RejectPortfolioShareRequest
  ) extends zio.aws.servicecatalog.model.RejectPortfolioShareRequest.ReadOnly {
    override val acceptLanguage: Option[AcceptLanguage] = scala
      .Option(impl.acceptLanguage())
      .map(value =>
        zio.aws.servicecatalog.model.primitives.AcceptLanguage(value)
      )
    override val portfolioId: Id =
      zio.aws.servicecatalog.model.primitives.Id(impl.portfolioId())
    override val portfolioShareType
        : Option[zio.aws.servicecatalog.model.PortfolioShareType] = scala
      .Option(impl.portfolioShareType())
      .map(value => zio.aws.servicecatalog.model.PortfolioShareType.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.servicecatalog.model.RejectPortfolioShareRequest
  ): zio.aws.servicecatalog.model.RejectPortfolioShareRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-servicecatalog_2.13-7.21.15.2-sources.jar: zio/aws/servicecatalog/model/RejectPortfolioShareRequest.scala <==
package zio.aws.servicecatalog.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.servicecatalog.model.primitives.{Id, AcceptLanguage}
import scala.jdk.CollectionConverters._
final case class RejectPortfolioShareRequest(
    acceptLanguage: Optional[AcceptLanguage] = Optional.Absent,
    portfolioId: Id,
    portfolioShareType: Optional[
      zio.aws.servicecatalog.model.PortfolioShareType
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.servicecatalog.model.RejectPortfolioShareRequest = {
    import RejectPortfolioShareRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.servicecatalog.model.RejectPortfolioShareRequest
      .builder()
      .optionallyWith(
        acceptLanguage.map(value =>
          AcceptLanguage.unwrap(value): java.lang.String
        )
      )(_.acceptLanguage)
      .portfolioId(Id.unwrap(portfolioId): java.lang.String)
      .optionallyWith(portfolioShareType.map(value => value.unwrap))(
        _.portfolioShareType
      )
      .build()
  }
  def asReadOnly
      : zio.aws.servicecatalog.model.RejectPortfolioShareRequest.ReadOnly =
    zio.aws.servicecatalog.model.RejectPortfolioShareRequest
      .wrap(buildAwsValue())
}
object RejectPortfolioShareRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.servicecatalog.model.RejectPortfolioShareRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.servicecatalog.model.RejectPortfolioShareRequest =
      zio.aws.servicecatalog.model.RejectPortfolioShareRequest(
        acceptLanguage.map(value => value),
        portfolioId,
        portfolioShareType.map(value => value)
      )
    def acceptLanguage: Optional[AcceptLanguage]
    def portfolioId: Id
    def portfolioShareType
        : Optional[zio.aws.servicecatalog.model.PortfolioShareType]
    def getAcceptLanguage: ZIO[Any, AwsError, AcceptLanguage] =
      AwsError.unwrapOptionField("acceptLanguage", acceptLanguage)
    def getPortfolioId: ZIO[Any, Nothing, Id] = ZIO.succeed(portfolioId)
    def getPortfolioShareType
        : ZIO[Any, AwsError, zio.aws.servicecatalog.model.PortfolioShareType] =
      AwsError.unwrapOptionField("portfolioShareType", portfolioShareType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.servicecatalog.model.RejectPortfolioShareRequest
  ) extends zio.aws.servicecatalog.model.RejectPortfolioShareRequest.ReadOnly {
    override val acceptLanguage: Optional[AcceptLanguage] =
      zio.aws.core.internal
        .optionalFromNullable(impl.acceptLanguage())
        .map(value =>
          zio.aws.servicecatalog.model.primitives.AcceptLanguage(value)
        )
    override val portfolioId: Id =
      zio.aws.servicecatalog.model.primitives.Id(impl.portfolioId())
    override val portfolioShareType
        : Optional[zio.aws.servicecatalog.model.PortfolioShareType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.portfolioShareType())
        .map(value =>
          zio.aws.servicecatalog.model.PortfolioShareType.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.servicecatalog.model.RejectPortfolioShareRequest
  ): zio.aws.servicecatalog.model.RejectPortfolioShareRequest.ReadOnly =
    new Wrapper(impl)
}
